diff Core/DicomFormat/DicomMap.cpp @ 67:9193041c8018

merge
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:48:01 +0200
parents c996319e90bc
children b8dfde8d64e8
line wrap: on
line diff
--- a/Core/DicomFormat/DicomMap.cpp	Tue Sep 11 12:19:42 2012 +0200
+++ b/Core/DicomFormat/DicomMap.cpp	Sun Sep 16 09:48:01 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -23,10 +23,10 @@
 #include <stdio.h>
 #include <memory>
 #include "DicomString.h"
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 
-namespace Palanthir
+namespace Orthanc
 {
   static DicomTag patientTags[] =
   {
@@ -178,7 +178,7 @@
 
     if (it == map_.end())
     {
-      throw PalanthirException("Inexistent tag");
+      throw OrthancException("Inexistent tag");
     }
     else
     {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium